 # nr       
 # year    
 # volume   
 # issue
 # doctype    
 # title
 # nauthors   
 # authors  : authors' names separated by " & "
 # ncountries
 # countries: countries authors are affiliated with separated by " & "
 # USA      : TRUE if at least one author is affiliated with a US institution
 # DE       :  TRUE if at least one author is affiliated with a German institution
 # OTHER    : TRUE if at least one author is affiliated with an institution from a country other than the US or Germany
 # collab   :  TRUE if authors from at least two countries are involved
 # col_DE   : TRUE if article is an international collaboration involving a German institution
 # col_DE_US: TRUE if article is an international collaboration involving a German and a US institution

setwd("/Users/kliegl/documents/manuscripts/APS")
library(ggplot2)

rm(list=ls())
load("psysci_collabsv4.rda")

# AUTHORS
# Angele solution 
for(i in 1:nrow(ps)) ps$nauthors[i] <- length(unique(strsplit(ps$authors[i], split = " & ")[[1]]))
for(i in 1:nrow(ps)) ps$ncountries[i] <- length(unique(strsplit(ps$countries[i], split = " & ")[[1]]))

# Kliegl solution
# several authors
ps$sevauthors <- FALSE
ps$sevauthors[grep("&", ps$authors)] <- TRUE

# n of authors
temp <- gregexpr("&", ps$authors)

# single authors
single <- numeric()
for (i in 1:nrow(temp)) single[i] <- attr(temp[[i]],"match.length")[1]
ps$nau[single==-1] <- 1  

# n of multiple authors
ix <- which(single==1)
for (i in ix)  ps$nau[i] <- length(temp[[i]]) + 1

# COUNTRIES
# several countries
ps$sevcountries <- FALSE
ps$sevcountries[grep("&", ps$countries)] <- TRUE

# n of countries
temp <- gregexpr("&", ps$countries)

# single countries
single <- numeric()
for (i in 1:nrow(temp)) single[i] <- attr(temp[[i]],"match.length")[1]
ps$ncnt[single==-1] <- 1  

# n of multiple countries
ix <- which(single==1)
for (i in ix)  ps$ncnt[i] <- length(temp[[i]]) + 1



table(ps$year, ps$collab)
table(ps$collab,ps$USA)

ps2 <- melt(ps, id=c("year","collab", "USA", "DE"), measure=c("nauthors", "ncountries"))

# Graph 1
xt1 <- cast(ps2, year + collab ~ ., length, subset=variable=="ncountries", add.missing=TRUE)
xt1[is.na(xt1[3]), 3] <- 0
names(xt1)[3] <- "Count"
names(xt1)[1] <- "Year"
xt1$Year <- as.numeric(xt1$Year)+1989
qplot(Year, log(Count), colour=collab, data=xt1, geom=c("point", "line"))

# Graph 2
xt2 <- cast(ps2, year ~ collab, length, subset=variable=="ncountries", add.missing=TRUE)
xt2$Count <- (xt2[ ,2]+xt2[ ,3])
xt2$Percentage <- 100*xt2[ ,3]/(xt2[ ,2]+xt2[ ,3])
xt2$Year <- as.numeric(xt2$year)+1989

#qplot(Year, Percentage, data=xt2, geom=c("point", "smooth"), method="lm", size=Count)
p <- qplot(Year, Percentage, data=xt2, geom=c("point", "smooth"), method="lm")
p + geom_text(aes(vjust=-.5, label=Count))
ggsave(file="Kliegl.APSObserver.Figure2.V2.pdf", scale=1.5)

# Determining the contribution for 2- to 4-author papers
ps2.na <- melt(ps[ps$nauthors>1 & ps$nauthors <=4,], id=c("year","collab", "nauthors"), measure=c("ncountries"))
xt2.na <- cast(ps2.na, year+nauthors ~ collab, length, subset=variable=="ncountries", add.missing=TRUE)
xt2.na[is.na(xt2.na[4]), 4] <- 0
xt2.na$Count <- (xt2.na[ ,3]+xt2.na[ ,4])
xt2.na$Percentage <- 100*xt2.na[ ,4]/(xt2.na[ ,3]+xt2.na[ ,4])
xt2.na$Year <- as.numeric(xt2.na$year)+1989

p <- qplot(Year, Percentage, colour=nauthors,group=nauthors, data=xt2.na, geom=c("point", "smooth"), method="lm")
p + geom_text(aes(vjust=-.5, label=Count))
ggsave(file="Kliegl.APSObserver.Figure3.V2.pdf", scale=1.5)

NAuthor <- as.numeric(as.character(xt2.na$nauthors))-2  # dummy coding with n=2 to zero.
summary(lm(Percentage ~ Year*NAuthor, data=xt2.na))

# Graph 2a by US participation
xt2a <- cast(ps2, year+USA ~ collab, length, subset=variable=="ncountries", add.missing=TRUE)
xt2a[is.na(xt2a[,4]), 4] <- 0
xt2a$Count <- (xt2a[ ,3]+xt2a[ ,4])
xt2a$Percentage <- xt2a[ ,4]/(xt2a[ ,3]+xt2a[ ,4])
xt2a$Year <- as.numeric(xt2a$year)+1989

qplot(Year, Percentage, data=xt2a, colour=USA, geom=c("point", "smooth"), method="lm", size=Count)
p <- qplot(Year, Percentage, data=xt2a,  colour=USA, geom=c("point", "smooth"), method="lm")
p + geom_text(aes(vjust=-.5, label=Count))


# Graph 3: w/o single-author papers
ps3 <- melt(ps[ps$nauthors>1, ], id=c("year", "collab", "USA"), measure=c("nauthors", "ncountries"))

xt3 <- cast(ps3, year ~ ., mean, subset=variable=="nauthors", add.missing=TRUE)
xt3$Year <- as.numeric(xt3$year)+1989
names(xt3)[2] <- "NAuthors"

qplot(Year, NAuthors, data=xt3, geom=c("point", "line", "smooth"), method="lm",
ytitle="N of authors per paper")

xt2$NAuthors2 <- xt3$NAuthors
summary(lm(Percentage ~ Year, data=xt2))
summary(lm(NAuthors ~ Year, data=xt2))

cor(xt2[  , c("Year", "Percentage", "NAuthors", "NAuthors2")])
cor(xt2[  , c("Year", "Percentage",  "NAuthors2")])

# Graph 4: at-least one US author
xt4 <- cast(ps2, year ~ USA, length, subset=variable=="ncountries", add.missing=TRUE)
xt4$Count <- (xt4[ ,2]+xt4[ ,3])
xt4$Percentage <- xt4[ ,3]/(xt4[ ,2]+xt4[ ,3])
xt4$Year <- as.numeric(xt4$year)+1989

qplot(Year, Percentage, data=xt4, geom=c("point", "smooth"), method="lm", size=Count)
p <- qplot(Year, Percentage, data=xt4, geom=c("point", "smooth"), method="lm")
p + geom_text(aes(vjust=-.5, label=Count))

# Graph 5: at-least one Germany author
xt4 <- cast(ps2, year ~ DE, length, subset=variable=="ncountries", add.missing=TRUE)
xt4$Count <- (xt4[ ,2]+xt4[ ,3])
xt4$Percentage <- xt4[ ,3]/(xt4[ ,2]+xt4[ ,3])
xt4$Year <- as.numeric(xt4$year)+1989

qplot(Year, Percentage, data=xt4, geom=c("point", "smooth"), method="lm", size=Count)
p <- qplot(Year, Percentage, data=xt4, geom=c("point", "smooth"), method="lm")
p + geom_text(aes(vjust=-.5, label=Count))

# Graph 6: collab percentage for US vs. non-US 
ps2.nc <- melt(ps, id=c("year","collab", "USA"), measure=c("ncountries"))
xt2.nc <- cast(ps2.nc, year+USA ~ collab, length, add.missing=TRUE)
xt2.nc[is.na(xt2.nc[4]), 4] <- 0
xt2.nc$Count <- (xt2.nc[ ,3]+xt2.nc[ ,4])
xt2.nc$Collab_Percentage <- 100*xt2.nc[ ,4]/(xt2.nc[ ,3]+xt2.nc[ ,4])
xt2.nc$Year <- as.numeric(xt2.nc$year)+1989

p <- qplot(Year, Collab_Percentage, colour=USA,group=USA, data=xt2.nc, geom=c("point", "smooth"), method="lm")
p + geom_text(aes(vjust=-.5, label=Count))

# Graph 7: USA percentage for collab vs no-collab
xt5.nc <- cast(ps2.nc, year+collab ~ USA, length, add.missing=TRUE)
xt5.nc[is.na(xt5.nc[3]), 3] <- 0
xt5.nc$Count <- (xt5.nc[ ,3]+xt5.nc[ ,4])
xt5.nc$US_Percentage <- 100*xt5.nc[ ,4]/(xt5.nc[ ,3]+xt5.nc[ ,4])
xt5.nc$Year <- as.numeric(xt5.nc$year)+1989


p <- qplot(Year, US_Percentage, colour=collab,group=collab, data=xt5.nc, geom=c("point", "smooth"), method="lm")
p + geom_text(aes(vjust=-.5, label=Count))

# Graph 8: log(n of pubs) by collab x USA 
# linear regression 
data <- cast(ps2.nc, year+USA+collab ~., length, subset=year<="2007", add.missing=TRUE)
data[is.na(data[4]), 4] <- 0
data$lcnt <- log(data[,4]+1)
data$year <- as.numeric(data$year)
summary(lm(lcnt ~ year*collab*USA, data=data))

levels(data$USA) <- c("0 US author", ">=1 US author")
levels(data$collab) <- c("single country", "several countries")

p <- qplot(year, lcnt, colour=collab,group=collab, facets= . ~ USA, data=data, geom=c("point", "smooth"), method="lm")
p 

p <- qplot(year, lcnt, colour=USA,group=USA, facets= . ~ collab, data=data, geom=c("point", "smooth"), method="lm")
p 
